package com.zbf.system.service;

import java.util.List;

import com.zbf.system.domain.TRkWareNoticeBak;

/**
 * 入库通知单历史表Service接口
 *
 * @author tony
 * @date 2024-06-18
 */
public interface ITRkWareNoticeBakService
{
    /**
     * 查询入库通知单历史表
     *
     * @param id 入库通知单历史表主键
     * @return 入库通知单历史表
     */
    public TRkWareNoticeBak selectTRkWareNoticeBakById(String id);

    /**
     * 查询入库通知单历史表列表
     *
     * @param tRkWareNoticeBak 入库通知单历史表
     * @return 入库通知单历史表集合
     */
    public List<TRkWareNoticeBak> selectTRkWareNoticeBakList(TRkWareNoticeBak tRkWareNoticeBak);

    /**
     * 新增入库通知单历史表
     *
     * @param tRkWareNoticeBak 入库通知单历史表
     * @return 结果
     */
    public int insertTRkWareNoticeBak(TRkWareNoticeBak tRkWareNoticeBak);

    /**
     * 修改入库通知单历史表
     *
     * @param tRkWareNoticeBak 入库通知单历史表
     * @return 结果
     */
    public int updateTRkWareNoticeBak(TRkWareNoticeBak tRkWareNoticeBak);

    /**
     * 批量删除入库通知单历史表
     *
     * @param ids 需要删除的入库通知单历史表主键集合
     * @return 结果
     */
    public int deleteTRkWareNoticeBakByIds(String[] ids);

    /**
     * 删除入库通知单历史表信息
     *
     * @param id 入库通知单历史表主键
     * @return 结果
     */
    public int deleteTRkWareNoticeBakById(String id);

    /**
     * 批量禁用入库通知单历史表
     *
     * @param ids 需要禁用的入库通知单历史表主键集合
     * @return 结果
     */
    public int disabledTRkWareNoticeBakByIds(String[] ids);

    /**
     * 批量启用入库通知单历史表
     *
     * @param ids 需要启用的入库通知单历史表主键集合
     * @return 结果
     */
    public int enableTRkWareNoticeBakByIds(String[] ids);

    /**
     * 改变状态
     *
     * @param tRkWareNoticeBak
     * @return 结果
     */
    public int updateStatus(TRkWareNoticeBak tRkWareNoticeBak);
}

